from zamtelsms.smsapi.zamtel import ZamtelSMSApi
#instatiate the sms class
zamtel_sms = ZamtelSMSApi()

def send_sms(phone_number, message):
    response = zamtel_sms.send_sms(phone_number,message)
    return response
    


from setuptools import setup, find_packages

setup(
    name='zamtelsms',
    packages = find_packages(),
    version='0.0.4',
    description='A small python Package for Zamtel bulk SMS API',
    author='Mathews Musukuma',
    author_email='sikaili99@gmail.com',
    url='https://github.com/Mathewsmusukuma/zamtel-sms',
    py_modules=['zamtelsms'],
    install_requires=['requests','python-decouple'],
    license='MIT License',
    zip_safe=False,
    keywords='zamtel sms package',
      classifiers=[
    'Development Status :: 3 - Alpha',     
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',  
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
  ]
    )



from decouple import config
import requests
import  json

class ZamtelSMSApi():
    """
    This simple code is used to send notification messages to users
    using the Zamtel bulk SMS API 
    """
    api_key=config("API_KEY")
    sender_id=config("SENDER_ID")
    base_url=config("BASE_URL")

    def send_sms(self,phone_number, message):
        response = requests.post(f"{self.base_url}api_key/{self.api_key}/contacts/{phone_number}/senderId/{self.sender_id}/message/{message}")
        return json.loads(response.text)
